Intermediate
============

Customize sub-parts of your MLO program (e.g., hypergradient calculation).

Intermediate 1: :doc:`Distributed training <intermediate_distributed>`

Intermediate 2: :doc:`Custom hypergradient <intermediate_hypergradient>`

.. toctree::
   :maxdepth: 1
   :hidden:

   Distributed Training <intermediate_distributed.rst>
   Custom Hypergradient<intermediate_hypergradient.rst>
